@@ -32,7 +32,7 @@ using namespace std;
 
 Baby::Baby(double x,double y) :Black(x,y) {
   acceleration = 1.0;
-  radius = 0.1;
+  realRadius = 0.1; radius=realRadius;
   crashTolerance = 3;
   horizon=3.0;
   position[2] = Game::current->map->getHeight(position[0],position[1]) + radius;
