@@ -89,11 +89,13 @@ Ball::Ball() :Animated() {
   no_physics=0;
   inPipe=0;
 
-  for(i=0;i<NUM_MODS;i++)
+  for(i=0;i<NUM_MODS;i++) {
 	modTimeLeft[i] = 0.0;
+	modTimePhaseIn[i] = 0.0;
+  }
 
   identityMatrix(rotations);
-  texture = loadTexture("ice.png"); //textures[0];
+  texture = loadTexture("ice.png");
 }
 Ball::~Ball() {}
 
@@ -105,6 +107,7 @@ void Ball::draw() {
   GLfloat color[4];
   GLfloat specular[4];
   double blend;
+  double phase;
 
   for(i=0;i<3;i++)
 	color[i] = primaryColor[i];
@@ -128,9 +131,14 @@ void Ball::draw() {
   //glScalef(radius,radius,radius);
   //glCallList(loresSphere);
   if(modTimeLeft[MOD_GLASS]) {
+
+	phase=min(modTimePhaseIn[MOD_GLASS]/2.0,1.0);
     if(modTimeLeft[MOD_GLASS] > 0)
-      blend = min((double) modTimeLeft[MOD_GLASS],1.0);
-    else blend = 1.0;
+	  phase=min(modTimeLeft[MOD_GLASS]/2.0,phase);
+	else
+	  phase=1.0;
+	blend = phase;
+
     
     color[0] = 0.8 * blend + color[0] * (1.0 - blend); 
     color[1] = 0.8 * blend + color[1] * (1.0 - blend); 
@@ -142,9 +150,13 @@ void Ball::draw() {
     shininess = 50.0 * blend + shininess * (1.0 - blend);
     glEnable(GL_BLEND);
   } else if(modTimeLeft[MOD_FROZEN]) {
+
+	phase=min(modTimePhaseIn[MOD_FROZEN]/2.0,1.0);
     if(modTimeLeft[MOD_FROZEN] > 0)
-      blend = min((double) modTimeLeft[MOD_FROZEN],1.0);
-    else blend = 1.0;
+	  phase=min(modTimeLeft[MOD_FROZEN]/2.0,phase);
+	else
+	  phase=1.0;
+	blend=phase;
 
     color[0] = 0.4 * blend + color[0] * (1.0 - blend); 
     color[1] = 0.4 * blend + color[1] * (1.0 - blend); 
@@ -178,8 +190,14 @@ void Ball::draw() {
   if(modTimeLeft[MOD_SPIKE]) {
     glPushAttrib(GL_ENABLE_BIT);
     glColor4f(1.0,1.0,1.0,1.0);
-	if(modTimeLeft[MOD_SPIKE] >= 0.0 && modTimeLeft[MOD_SPIKE] < 2.0)
-	  glScalef(modTimeLeft[MOD_SPIKE]*0.25+0.5,modTimeLeft[MOD_SPIKE]*0.25+0.5,modTimeLeft[MOD_SPIKE]*0.25+0.5);
+
+	phase=min(modTimePhaseIn[MOD_SPIKE]/2.0,1.0);
+    if(modTimeLeft[MOD_SPIKE] > 0)
+	  phase=min(modTimeLeft[MOD_SPIKE]/2.0,phase);
+	else
+	  phase=1.0;
+	glScalef(0.5+0.5*phase,0.5+0.5*phase,0.5+0.5*phase);
+
 	for(i=0;i<3;i++)
 	  color[i] = secondaryColor[i];
 	glColor3f(1.0,1.0,1.0);
@@ -373,12 +391,35 @@ void Ball::draw2() {
 
 void Ball::tick(Real time) {
   int i;
+  double phase;
+
+  for(i=0;i<NUM_MODS;i++) {
+	if(!modTimeLeft[i]) modTimePhaseIn[i]=0.0;
+	else modTimePhaseIn[i]+=time;
 
-  for(i=0;i<NUM_MODS;i++)
 	if(modTimeLeft[i] > 0.0) { 
 	  modTimeLeft[i] -= time;
 	  if(modTimeLeft[i] < 0) modTimeLeft[i] = 0.0;
-	}
+	}  
+  }
+
+  radius=realRadius;
+  if(modTimeLeft[MOD_LARGE]) {
+	phase=min(modTimePhaseIn[MOD_LARGE]/5.0,1.0);
+    if(modTimeLeft[MOD_LARGE] > 0)
+	  phase=min(modTimeLeft[MOD_LARGE]/3.0,phase);
+	else
+	  phase=1.0;
+	radius *= 1.0 + phase;
+  }
+  if(modTimeLeft[MOD_SMALL]) {
+	phase=min(modTimePhaseIn[MOD_SMALL]/5.0,1.0);
+    if(modTimeLeft[MOD_SMALL] > 0)
+	  phase=min(modTimeLeft[MOD_SMALL]/3.0,phase);
+	else
+	  phase=1.0;
+	radius /= 1.0 + phase;
+  }
   physics(time);
 }
 
@@ -392,9 +433,12 @@ Boolean Ball::physics(Real time) {
 	rotation[0] += time * 7.0 * (frand((int) Game::current->gameTime + (int) this)-0.5); //sin(Game::current->gameTime*M_PI);
 	rotation[1] += time * 7.0 * (frand(47 + (int) Game::current->gameTime + (int) this)-0.5); //cos(Game::current->gameTime*M_PI);
   }
-	
-  rotateX(-rotation[1]*time*2.0*M_PI*radius,rotations);
-  rotateY(-rotation[0]*time*2.0*M_PI*radius,rotations);
+
+  /*  rotateX(-rotation[1]*time*2.0*M_PI*radius,rotations);
+	  rotateY(-rotation[0]*time*2.0*M_PI*radius,rotations);*/
+  rotateX(-rotation[1]*time*2.0*M_PI*0.3*0.3/radius,rotations);
+  rotateY(-rotation[0]*time*2.0*M_PI*0.3*0.3/radius,rotations);
+
 
   int i;
   Real t=0;
@@ -471,8 +515,8 @@ Boolean Ball::physics(Real time) {
 		  Coord3d center; assign(position,center);
 		  center[2] = map->getWaterHeight(center[0],center[1]);
 		  Coord3d vel;
-		  vel[0]=-rotation[0] * 0.3;
-		  vel[1]=-rotation[1] * 0.3;
+		  vel[0]=-rotation[0] * radius; //0.3;
+		  vel[1]=-rotation[1] * radius; //0.3;
 		  vel[2]=0.2;
 		  rotation[0] *= 0.9;
 		  rotation[1] *= 0.9;
@@ -730,6 +774,7 @@ void Ball::generateSandDebris() {
   d->primaryColor[2] = 0.1 + 0.3*frandom();
   d->life = 0.5 + 1.0 * frandom();
   d->friction = 0.0;
+  d->tick(0.0);
 }
 void Ball::generateDebris(GLfloat color[4]) {
   Coord3d pos,vel;
@@ -745,6 +790,7 @@ void Ball::generateDebris(GLfloat color[4]) {
   d->primaryColor[2] = color[2];
   d->life = 0.5 + 1.0 * frandom();
   d->friction = 0.0;
+  d->tick(0.0);
 }
 
 void Ball::handleBallCollisions() {
@@ -929,7 +975,17 @@ void Ball::handlePipes() {
 	if(distance > pipe->radius || l == 0.0 || l == 1.0) { 
 	  /* Ball is on the outside */
 	  // note. If <inPipe> then we are already inside another pipe. No collision!
-	  if(distance < pipe->radius + radius && l != 0.0 && l != 1.0 && !inPipe) {
+	  if(pipe->radius > 0.1 && pipe->radius < radius && distance < radius) {
+		/* Added code to bounce of too small pipes, except for *realy* thin pipes which
+		 are meant to be lifts */
+		Coord3d normal; assign(v1,normal); normalize(normal);
+		double speed=-dotProduct(velocity,normal);
+		if(speed > 0) 
+		  for(i=0;i<3;i++) velocity[i] += speed * normal[i] * 1.5;
+		double correction = radius - distance;
+		for(i=0;i<3;i++)
+		  for(i=0;i<3;i++) position[i] += correction * normal[i];
+	  } else  if(distance < pipe->radius + radius && l != 0.0 && l != 1.0 && !inPipe) {
 		/* Collision from outside */
 		if(pipe->flags & PIPE_SOFT_ENTER & l < 0.2 / pipeLength) continue;
 		if(pipe->flags & PIPE_SOFT_EXIT & l > 1.0 - 0.2 / pipeLength) continue;
