@@ -35,7 +35,11 @@
 #define MOD_FLOAT      6
 // this is not real mod. Used only for special modPill's
 #define MOD_EXTRA_LIFE 7
-#define NUM_MODS       8
+
+#define MOD_SMALL      8
+#define MOD_LARGE      9
+
+#define NUM_MODS       10
 
 #define DIE_CRASH  0
 #define DIE_FF     1
@@ -59,12 +63,14 @@ class Ball : public Animated {
   static void init();
   static void reset();
 
-
   Coord3d velocity;
   int inTheAir,inPipe;
-  float modTimeLeft[NUM_MODS],rotation[2];
+  float modTimeLeft[NUM_MODS],  modTimePhaseIn[NUM_MODS];
+  float rotation[2];
 
-  Real radius,friction,gravity,bounceFactor;
+  // radius is the *effective* radius, realRadius the real one
+  Real radius,realRadius;  
+  Real friction,gravity,bounceFactor;
   Real crashTolerance;
   int resolution,no_physics;
 
