@@ -176,18 +176,22 @@ void EditMode::display() {
 
   displayFrameRate();
   char str[256];
+
   Enter2DMode();
-  glColor4f(0.0,0.0,0.0,0.5);
+  glDisable(GL_TEXTURE_2D);
+  glColor4f(0.5,0.5,0.5,0.5);
   glBegin(GL_POLYGON); 
   glVertex2i(0,0); glVertex2i(screenWidth,0); glVertex2i(screenWidth,160); glVertex2i(0,160);
   glEnd();
   glLineWidth(1.0);
   glColor4f(0.8,0.8,0.8,0.8);
   glBegin(GL_LINES); glVertex2i(0,161); glVertex2i(screenWidth,161); glEnd();
+  glEnable(GL_TEXTURE_2D);
 
   sprintf(str,"Raise: %f",raise);
   glColor3f(1.0,1.0,1.0);
   draw2DString(infoFont,str,10,20+0*18,255,255,0);
+
   sprintf(str,"Pos: %d,%d",x,y);
   draw2DString(infoFont,str,10,20+1*18,255,255,0);
   if(menuChoise == MENU_HILLS) {
@@ -198,7 +202,7 @@ void EditMode::display() {
 	draw2DString(infoFont,str,10,20+2*18,255,255,0);
 	glColor4f(color[0],color[1],color[2],color[3]);
 	glBegin(GL_POLYGON); 
-	glVertex2i(180,18+1*18); glVertex2i(200,18+1*18); glVertex2i(200,14+2*18); glVertex2i(180,14+2*18);
+	glVertex2i(185,17+1*18); glVertex2i(203,17+1*18); glVertex2i(203,13+2*18); glVertex2i(185,13+2*18);
 	glEnd();
   }
   glColor3f(1.0,1.0,1.0);
