@@ -39,12 +39,13 @@ class Game {
   int localPlayers,isNight,startTime,currentLevelSet,useGrid;
   double fogThickness,wantedFogThickness;
   double restartBonusTime;
-  double jumpFactor;
+  double jumpFactor,oxygenFactor;
 
   class Player *player1;
   class Map *map;
   Real gameTime;
   class Gamer *gamer;
+  class Weather *weather;
 
   static Game *current;
 
