@@ -51,6 +51,7 @@
 #include "animator.h"
 #include "mainMode.h"
 #include "fountain.h"
+#include "weather.h"
 
 using namespace std;
 
@@ -526,7 +527,7 @@ SCM_DEFINE(set_bonus_level,"set-bonus-level",1,0,0,(SCM name),
 }
 
 /************* sign ************/
-SCM_DEFINE(sign,"sign",6,0,0,(SCM text, SCM scale, SCM rotation, SCM duration, SCM x, SCM y),
+SCM_DEFINE(sign,"sign",6,1,0,(SCM text, SCM scale, SCM rotation, SCM duration, SCM x, SCM y, SCM z),
 		   "Creates a new sign. duration<0 lasts forever.")
 #define FUNC_NAME s_sign
 {
@@ -537,7 +538,10 @@ SCM_DEFINE(sign,"sign",6,0,0,(SCM text, SCM scale, SCM rotation, SCM duration, S
 	  Coord3d pos;
 	  pos[0] = scm_num2dbl(x,FUNC_NAME);
 	  pos[1] = scm_num2dbl(y,FUNC_NAME);
-	  pos[2] = Game::current->map->getHeight(pos[0],pos[1]) + 2.0;
+	  if(SCM_NUMBERP(z))
+		pos[2] = scm_num2dbl(z,FUNC_NAME);
+	  else
+		pos[2] = Game::current->map->getHeight(pos[0],pos[1]) + 2.0;
 	  Sign *s = new Sign(sname,scm_num2dbl(duration,FUNC_NAME),scm_num2dbl(scale,FUNC_NAME),scm_num2dbl(rotation,FUNC_NAME),pos);
 	  return smobAnimated_make(s);
 	}
@@ -846,6 +850,30 @@ SCM_DEFINE (set_wind, "set-wind", 3, 0, 0,
 }
 #undef FUNC_NAME
 
+/**************** snow *************/
+SCM_DEFINE (snow, "snow", 1, 0, 0,
+	    (SCM strength),
+	    "Turns on snow, 0 <= strength <= 1.0 ")
+#define FUNC_NAME s_snow
+{
+  SCM_ASSERT(SCM_NUMBERP(strength),strength,SCM_ARG1,FUNC_NAME);
+  Game::current->weather->snow(scm_num2dbl(strength,FUNC_NAME));
+  return SCM_UNSPECIFIED;
+}
+#undef FUNC_NAME
+
+/**************** rain *************/
+SCM_DEFINE (rain, "rain", 1, 0, 0,
+	    (SCM strength),
+	    "Turns on rain, 0 <= strength <= 1.0 ")
+#define FUNC_NAME s_rain
+{
+  SCM_ASSERT(SCM_NUMBERP(strength),strength,SCM_ARG1,FUNC_NAME);
+  Game::current->weather->rain(scm_num2dbl(strength,FUNC_NAME));
+  return SCM_UNSPECIFIED;
+}
+#undef FUNC_NAME
+
 /*********** difficulty ***********/
 SCM_DEFINE (difficulty, "difficulty", 0, 0, 0,(),"Returns the difficulty we are currently playing on.")
 { return scm_long2num(Settings::settings->difficulty); }
@@ -868,6 +896,17 @@ SCM_DEFINE (jump, "jump", 1, 0, 0, (SCM v), "Scales maximum jump height of playe
 }
 #undef FUNC_NAME
 
+/*********** scale-oxygen ************/
+SCM_DEFINE (scale_oxygen, "scale-oxygen", 1, 0, 0, (SCM v), "Scales how long player can be under water")
+#define FUNC_NAME s_jump
+{ 
+  SCM_ASSERT(SCM_NUMBERP(v),v,SCM_ARG1,FUNC_NAME);
+  if(Game::current)
+	Game::current->oxygenFactor=scm_num2dbl(v,FUNC_NAME);
+}
+#undef FUNC_NAME
+
+
 /************ set-speed ************/
 SCM_DEFINE (set_speed, "set-speed", 2, 0, 0, (SCM obj,SCM speed), "Alters the speed of platforms or spikes")
 #define FUNC_NAME s_set_speed
@@ -1234,6 +1273,8 @@ SCM_GLOBAL_VARIABLE_INIT(s_mod_dizzy,"*mod-dizzy*",scm_long2num(MOD_DIZZY));
 SCM_GLOBAL_VARIABLE_INIT(s_mod_frozen,"*mod-frozen*",scm_long2num(MOD_FROZEN));
 SCM_GLOBAL_VARIABLE_INIT(s_mod_float,"*mod-float*",scm_long2num(MOD_FLOAT));
 SCM_GLOBAL_VARIABLE_INIT(s_mod_extra_life,"*mod-extra-life*",scm_long2num(MOD_EXTRA_LIFE));
+SCM_GLOBAL_VARIABLE_INIT(s_mod_large,"*mod-large*",scm_long2num(MOD_LARGE));
+SCM_GLOBAL_VARIABLE_INIT(s_mod_small,"*mod-small*",scm_long2num(MOD_SMALL));
 
 SCM_GLOBAL_VARIABLE_INIT(s_easy,"*easy*",scm_long2num(0));
 SCM_GLOBAL_VARIABLE_INIT(s_normal,"*normal*",scm_long2num(1));
