@@ -29,7 +29,7 @@
 using namespace std;
 
 HelpMode *HelpMode::helpMode;
-SDL_Surface *HelpMode::background, *HelpMode::moreHelp,*HelpMode::back;
+SDL_Surface *HelpMode::background, *HelpMode::moreHelp,*HelpMode::back,*HelpMode::backHigh;
 SDL_Surface *HelpMode::page0, *HelpMode::page1,*HelpMode::moreHelpHigh;
 
 void HelpMode::init() {
@@ -52,6 +52,10 @@ void HelpMode::init() {
   sprintf(str,"%s/images/return2menu.png",SHARE_DIR);
   back=IMG_Load(str);
   if(!back) { printf("Error: Failed to load %s\n",str); exit(0); } 
+  sprintf(str,"%s/images/return2menuHigh.png",SHARE_DIR);
+  backHigh=IMG_Load(str);
+  if(!backHigh) { printf("Error: Failed to load %s\n",str); exit(0); } 
+
   helpMode = new HelpMode();
 }
 HelpMode::HelpMode() {}
@@ -168,10 +172,10 @@ void HelpMode::display() {
 	  {" ",                  "Left mouse or spacebar is jump."},
 	  {" ",                  "Shift gives top speed when using keyboard."},
 	  {"Mr Black:",          "Your enemy. Defeat with Modpill - Spike."},
-	  {"Modpill - Speed:",   "Makes you go faster for short period of time."},
-	  {"Modpill - Spikes:",  "Weapon against Mr Black and grip for icy terrain."},
-	  {"Modpill - Freeze:",  "This will freeze you - avoid it."},
-	  {"Modpill - Glass:",   "Protects you from acid, but makes you more delicate."},
+	  {"Modpill Speed:",   "Makes you go faster for short period of time."},
+	  {"Modpill Spikes:",  "Weapon against Mr Black and grip for icy terrain."},
+	  {"Modpill Freeze:",  "This will freeze you - avoid it."},
+	  {"Modpill Glass:",   "Protects you from acid, but makes you more delicate."},
 	  {"Switch:",            "Activates/Deactivates some object/elemnt in the level."},
 	  {"Moving spike:",      "Obstacle to avoid."},
 	  {"Flag:",              "Collect for bonus points."},
@@ -189,8 +193,22 @@ void HelpMode::display() {
 	for(int i=0;i<20;i++) {
 	  //draw2DString(infoFont,text[i][0],screenWidth/2-310,screenHeight/2-200+i*20,220,220,64);
 	  //draw2DString(infoFont,text[i][1],screenWidth/2-150,screenHeight/2-200+i*20,220,220,64);
-	  Font::drawSimpleText(0,text[i][0],screenWidth/2-310,screenHeight/2-200+i*20,10.f, 10., 0.9,0.9,0.25,1.);
-	  Font::drawSimpleText(0,text[i][1],screenWidth/2-150,screenHeight/2-200+i*20,10., 10., 0.9,0.9,0.25,1.);
+	  if(screenWidth <= 640) {
+		Font::drawSimpleText(0,text[i][0],screenWidth/2-310,screenHeight/2-200+i*20+10,10.f, 10., 0.9,0.9,0.25,1.);
+		Font::drawSimpleText(0,text[i][1],screenWidth/2-150,screenHeight/2-200+i*20+10,10., 10., 0.9,0.9,0.25,1.);	  
+		Font::drawCenterSimpleText(0,"See also the forums at:",screenWidth/2,10,10.,10., 0.9,0.9,0.25,1.0);
+		Font::drawCenterSimpleText(0,"trackballs.theunix.org",screenWidth/2,30,10.,10., 0.9,0.9,0.25,1.0);
+	  } else if(screenWidth == 800) {
+		Font::drawSimpleText(0,text[i][0],screenWidth/2-330,screenHeight/2-200+i*20+10,10.f, 10., 0.9,0.9,0.25,1.);
+		Font::drawSimpleText(0,text[i][1],screenWidth/2-130,screenHeight/2-200+i*20+10,10., 10., 0.9,0.9,0.25,1.);	  
+		Font::drawCenterSimpleText(0,"See also the trackballs forums at:",screenWidth/2,30,20.,20., 0.9,0.9,0.25,1.0);
+		Font::drawCenterSimpleText(0,"trackballs.theunix.org",screenWidth/2,70,20.,20., 0.9,0.9,0.25,1.0);
+	  } else if(screenWidth >= 1024) {
+		Font::drawSimpleText(0,text[i][0],screenWidth/2-360,screenHeight/2-200+i*20,10.f, 10., 0.9,0.9,0.25,1.);
+		Font::drawSimpleText(0,text[i][1],screenWidth/2-100,screenHeight/2-200+i*20,10., 10., 0.9,0.9,0.25,1.);	  
+		Font::drawCenterSimpleText(0,"See also the trackballs forums at:",screenWidth/2,30,24.,24., 0.9,0.9,0.25,1.0);
+		Font::drawCenterSimpleText(0,"trackballs.theunix.org",screenWidth/2,80,24.,24., 0.9,0.9,0.25,1.0);
+	  }
 	}
 	//Leave2DMode();
   }
@@ -200,6 +218,12 @@ void HelpMode::display() {
   else
 	drawSurface(moreHelp,screenWidth-moreHelp->w,screenHeight-45,moreHelp->w,moreHelp->h);
 
+  if(selected == 1)
+	drawSurface(backHigh,-40,screenHeight-45,back->w,back->h);
+  else
+	drawSurface(back,-40,screenHeight-45,back->w,back->h);
+
+
   drawMousePointer();
   displayFrameRate();
 }
@@ -223,6 +247,8 @@ void HelpMode::idle(Real td) {
   Uint8 mouseState=SDL_GetMouseState(&mouseX,&mouseY);
   if(mouseX >= screenWidth-moreHelp->w && mouseY > screenHeight-50)
 	selected=0;
+  else if(mouseX <= back->w && mouseY > screenHeight-50)
+	selected=1;
   else 
 	selected=-1;
 
