@@ -38,7 +38,7 @@ class HelpMode : public GameMode {
   double timeLeft;
   int isExiting,selected,page;
   static SDL_Surface *background,*moreHelp,*moreHelpHigh;
-  static SDL_Surface *back,*page0,*page1;
+  static SDL_Surface *back,*backHigh,*page0,*page1;
 
   GLuint bgTexture,p0Texture,p1Texture;
   GLfloat texMinX, texMinY, texMaxX, texMaxY;
