@@ -21,6 +21,7 @@
 #include "general.h"
 #include "animated.h"
 #include "splash.h"
+#include "glHelp.h"
 
 using namespace std;
 
@@ -50,7 +51,14 @@ void Splash::draw2() {
   glEnable(GL_BLEND);
   glDisable(GL_LIGHTING);
   glColor4fv(primaryColor);
-  glPointSize(2.0);
+
+  if(screenWidth <= 800)
+	glPointSize(2.0);
+  else if(screenWidth == 1024)
+	glPointSize(3.0);
+  else if(screenWidth >= 1280)
+	glPointSize(4.0);
+
   glBegin(GL_POINTS);
   for(i=0;i<nDroplets;i++)
 	glVertex3f(positions[i][0],positions[i][1],positions[i][2]);
